#!/usr/bin/env python3
"""
Name Generator Method Package.

by BBaoVanC

!!! THIS PACKAGE WILL NOT WORK IF YOUR PROGRAM IS IN libnamegen/ !!!
This is a package which contains the various name generation methods used in
https://github.com/BBaoVanC/NameGenerator

Copyright (C) 2020 BBaoVanC
"""

# Imports
import libnamegen.classic  # NOQA
import libnamegen.random  # NOQA
